@@ -1,11 +1,11 @@
 from .modules import (
-    MAE,
     STFT,
     AutoEncoder1d,
     Bottleneck,
     Decoder1d,
     Discriminator1d,
     Encoder1d,
+    MAE1d,
     NoiserBottleneck,
     TanhBottleneck,
     VariationalBottleneck,
